@@ -346,6 +346,23 @@ class CloudPods:
             log.warn(f"Failed to request /servers/{server_id}: Error.\rerr msg is {str(e)}")
             return None
 
+    @enter_and_leave_function
+    def restart_server(self,server_id):
+        try:
+            url = self.__compute_url + f"/servers/{server_id}/restart"
+            payload={
+                "is_force": False,
+            }
+            rs = self.__session.post(url=url, json=payload,verify=False, timeout=600)
+            if rs.status_code != 200:
+                log.warn(f"Failed to request /servers/{server_id}/restart: Error. err msg is {str(rs.text)}")
+                return False
+            log.info(f"restart server {server_id} success.")
+            return True
+        except Exception as e:
+            log.error(f"Failed to request /servers/{server_id}/restart: Error.\rerr msg is {str(e)}")
+            return False
+
     @enter_and_leave_function
     def get_server_ip(self, server_id):
         server = self.get_server_detail(server_id)
@@ -542,8 +559,9 @@ if __name__ == '__main__':
     cloudpods = CloudPods('https://10.20.40.101:30500/v3', 'admin', 'jSj@2008')
     # rs=cloudpods.get_baremetal_hosts()
     # print(rs)
-    rs=cloudpods.get_server_detail("8c925c8e-752f-4358-8c3e-a80847732d91")
-    print(rs)
+    # rs=cloudpods.get_server_detail("8c925c8e-752f-4358-8c3e-a80847732d91")
+    # print(rs)
+    rs=cloudpods.restart_server("b868a4fb-05a0-4ca0-804a-acbd4d814ea7")
     # print(len(rs["hosts"]))
     # rs=cloudpods.get_baremetal_servers()
     # print(rs)
